==> xwiki-platform-url-default-3.1.1-sources.jar: org/xwiki/url/internal/standard/DomainHostResolver.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.url.internal.standard;

import org.xwiki.component.annotation.Component;
import org.xwiki.model.reference.WikiReference;
import org.xwiki.url.standard.HostResolver;

/**
 * Find wiki name based on the specified domain name.
 *
 * @version $Id$
 * @since 3.0M3
 */
@Component("domain")
public class DomainHostResolver implements HostResolver
{
    /**
     * {@inheritDoc}
     */
    public WikiReference resolve(String host)
    {
        String wiki;
        int pos = host.indexOf('.');
        if (pos > -1) {
            wiki = host.substring(0, pos);
        } else {
            wiki = host;
        }
        return new WikiReference(host);
    }
}

==> xwiki-platform-url-default-4.1.3-sources.jar: org/xwiki/url/internal/standard/DomainHostResolver.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.url.internal.standard;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.model.reference.WikiReference;
import org.xwiki.url.standard.HostResolver;

/**
 * Find wiki name based on the specified domain name.
 *
 * @version $Id$
 * @since 3.0M3
 */
@Component
@Named("domain")
@Singleton
public class DomainHostResolver implements HostResolver
{
    @Override
    public WikiReference resolve(String host)
    {
        String wiki;
        int pos = host.indexOf('.');
        if (pos > -1) {
            wiki = host.substring(0, pos);
        } else {
            wiki = host;
        }
        return new WikiReference(host);
    }
}
